@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.2"
+    version = "1.8.3"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -131,7 +131,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title if 'unknown' not in group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
-        payload = f"{payload} > Hi: {event.__dict__} \n\n"
+        payload = f"{payload} > Hi: {event.data} \n\n"
         payload = f"{payload} > Group: {group.__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
@@ -173,6 +173,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
             }
 
         }
-        for webhook_url in self.get_webhook_urls(group.project):
-            requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
+        if group.status == 0:
+            for webhook_url in self.get_webhook_urls(group.project):
+                requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
 
